from distutils.core import setup
setup(
      name='Cindxu',
      version='1.1.0',
      py_modules=['Cindxu'],
      author='xuli',
      author_email='xulicindy@163.com',
      url='http://www.headfirstlabs.com',
      description='A simple printer of nested lists for specific tab',
      )
